import { getDeviceList, getDeviceModifierList, addDeviceModifier, setDeviceModifier, queryLogList, setDeviceAdmin } from '@/api/admin'
import { parseTime } from '@/utils/index'
const state = {
  deviceData: [],
  modifierData: [],
  logData: []
}

const mutations = {
  GET_DEVICE: (state, data) => {
    if (data.length > 0) {
      data.forEach(item => {
        item.gmtModified = (parseTime(item.gmtModified))
        item.gmtCreated = (parseTime(item.gmtCreated))
      })
    }
    state.deviceData = data
  },
  GET_MODIFIER: (state, data) => {
    const fileData = []
    if (data.length > 0) {
      data.forEach(item => {
        const length = item.type.length
        const peopleType = length > 2 ? item.type.split(',') : item.type !== '0' ? [...item.type] : item.type
        item.type = peopleType
        if (item.type !== '0') {
          fileData.push(item)
        }
      })
    }
    state.modifierData = fileData
  },
  GET_Log: (state, data) => {
    if (data.length > 0) {
      data.forEach(item => {
        item.deviceLog.gmtModified = (parseTime(item.deviceLog.gmtModified))
        item.deviceLog.gmtCreated = (parseTime(item.deviceLog.gmtCreated))
      })
    }
    state.logData = data
  }
}

const actions = {
  // user login
  getDeviceData({ commit }, deviceParams) {
    return new Promise((resolve, reject) => {
      getDeviceList(deviceParams).then(response => {
        const { data } = response
        commit('GET_DEVICE', data.list)
        resolve()
      }).catch(error => {
        reject(error)
      })
    })
  },
  getDeviceModifierData({ commit }, modifierParams) {
    return new Promise((resolve, reject) => {
      getDeviceModifierList(modifierParams).then(response => {
        const { data } = response
        console.log(data)
        commit('GET_MODIFIER', data.list)
        resolve()
      }).catch(error => {
        reject(error)
      })
    })
  },
  addDeviceModifierData({ dispatch }, data) {
    return new Promise((resolve, reject) => {
      addDeviceModifier(data).then(response => {
        const { data } = response
        console.log(data)
        dispatch('getDeviceModifierData')
        // commit('GET_MODIFIER', data.list)
        resolve()
      }).catch(error => {
        reject(error)
      })
    })
  },
  setDeviceModifierData({ dispatch }, data) {
    return new Promise((resolve, reject) => {
      setDeviceModifier(data).then(response => {
        const { data } = response
        console.log(data)
        dispatch('getDeviceModifierData')
        // commit('GET_MODIFIER', data.list)
        resolve()
      }).catch(error => {
        reject(error)
      })
    })
  },
  queryLogData({ commit }, logParams) {
    return new Promise((resolve, reject) => {
      queryLogList(logParams).then(response => {
        const { data } = response
        console.log(data)
        commit('GET_Log', data.list)
        resolve()
      }).catch(error => {
        reject(error)
      })
    })
  },
  addDeviceAdminList({ commit }, data) {
    return new Promise((resolve, reject) => {
      setDeviceAdmin(data).then(response => {
        const { data } = response
        console.log(data)
        // dispatch('getDeviceModifierData')
        // commit('GET_MODIFIER', data.list)
        resolve()
      }).catch(error => {
        reject(error)
      })
    })
  }
}

export default {
  namespaced: true,
  state,
  mutations,
  actions
}
